a helper function that takes a fixest feols object (likely
from did2s) that plugs into honest_did. Note this function assumes
the event study coefficients are using i() syntax, e.g. i(rel_year).
This should also work for a TWFE event-study model estimated by feols.
get_honestdid_obj_did2s(est, coef_name = "rel_year")A list containing the vector of event-study coefficients beta, the
variance-covariance matrix of beta, V, and a vector of relative years,
event_time.
A fixest object, likely from did2s.
Character. The name of the event-study relative-year
variable name, from i(rel_year).